@@ -445,11 +445,11 @@ static byte* fil_encrypt_buf_for_non_full_checksum(
 	uint		srclen = size - unencrypted_bytes;
 	const byte*	src = src_frame + header_len;
 	byte*		dst = dst_frame + header_len;
-	uint32		dstlen = 0;
 
 	if (page_compressed) {
 		srclen = mach_read_from_2(src_frame + FIL_PAGE_DATA);
 	}
+	uint dstlen = srclen;
 
 	int rc = encryption_scheme_encrypt(src, srclen, dst, &dstlen,
 					   crypt_data, key_version,
@@ -516,7 +516,7 @@ static byte* fil_encrypt_buf_for_full_crc32(
 			      + FIL_PAGE_FCRC32_CHECKSUM);
 	const byte* src = src_frame + FIL_PAGE_FILE_FLUSH_LSN_OR_KEY_VERSION;
 	byte* dst = dst_frame + FIL_PAGE_FILE_FLUSH_LSN_OR_KEY_VERSION;
-	uint dstlen = 0;
+	uint dstlen = srclen;
 
 	ut_a(key_version != ENCRYPTION_KEY_VERSION_INVALID);
 
@@ -647,7 +647,6 @@ static dberr_t fil_space_decrypt_full_crc32(
 	/* Calculate the offset where decryption starts */
 	const byte* src = src_frame + FIL_PAGE_FILE_FLUSH_LSN_OR_KEY_VERSION;
 	byte* dst = tmp_frame + FIL_PAGE_FILE_FLUSH_LSN_OR_KEY_VERSION;
-	uint dstlen = 0;
 	bool corrupted = false;
 	uint size = buf_page_full_crc32_size(src_frame, NULL, &corrupted);
 	if (UNIV_UNLIKELY(corrupted)) {
@@ -656,6 +655,7 @@ static dberr_t fil_space_decrypt_full_crc32(
 
 	uint srclen = size - (FIL_PAGE_FILE_FLUSH_LSN_OR_KEY_VERSION
 			      + FIL_PAGE_FCRC32_CHECKSUM);
+	uint dstlen = srclen;
 
 	int rc = encryption_scheme_decrypt(src, srclen, dst, &dstlen,
 					   crypt_data, key_version,
@@ -711,8 +711,8 @@ static dberr_t fil_space_decrypt_for_non_full_checksum(
 	/* Calculate the offset where decryption starts */
 	const byte* src = src_frame + header_len;
 	byte* dst = tmp_frame + header_len;
-	uint32 dstlen = 0;
 	uint srclen = uint(physical_size) - header_len - FIL_PAGE_DATA_END;
+	uint dstlen = srclen;
 
 	if (page_compressed) {
 		srclen = mach_read_from_2(src_frame + FIL_PAGE_DATA);
@@ -907,7 +907,7 @@ static inline void fil_crypt_read_crypt_data(fil_space_t *space)
     return;
 
   const ulint zip_size= space->zip_size();
-  mtr_t mtr;
+  mtr_t mtr{nullptr};
   mtr.start();
   if (buf_block_t* b= buf_page_get_gen(page_id_t{space->id, 0}, zip_size,
                                        RW_S_LATCH, nullptr,
@@ -961,7 +961,7 @@ func_exit:
 	fil_crypt_start_converting = true;
 	mysql_mutex_unlock(&fil_crypt_threads_mutex);
 
-	mtr_t mtr;
+	mtr_t mtr{nullptr};
 	mtr.start();
 
 	/* 2 - get page 0 */
@@ -1684,7 +1684,7 @@ fil_crypt_get_page_throttle(
 
 	if (offset % (zip_size ? zip_size : srv_page_size)
 	    && DB_SUCCESS_LOCKED_REC
-	    != fseg_page_is_allocated(space, offset)) {
+	    != fseg_page_is_allocated(mtr, space, offset)) {
 		/* page is already freed */
 		return NULL;
 	}
@@ -1752,7 +1752,7 @@ fil_crypt_rotate_page(
 		return;
 	}
 
-	mtr_t mtr;
+	mtr_t mtr{nullptr};
 	mtr.start();
 	if (buf_block_t* block = fil_crypt_get_page_throttle(state,
 							     offset, &mtr,
@@ -1931,7 +1931,7 @@ fil_crypt_flush_space(
 	}
 
 	/* update page 0 */
-	mtr_t mtr;
+	mtr_t mtr{nullptr};
 	mtr.start();
 
 	if (buf_block_t* block = buf_page_get_gen(
